@@ -18,15 +18,21 @@ _METRIC_REGEX = "([0-9\\.]+)"
 class SageMakerClient(object):
     def __init__(self, aws_profile, aws_region, aws_role=None, external_id=None):
 
-        if aws_role and external_id:
+        if aws_role:
             logger.info("An IAM role and corresponding external id were provided. Attempting to assume that role...")
 
             sts_client = boto3.client('sts')
-            assumedRoleObject = sts_client.assume_role(
-                RoleArn=aws_role,
-                RoleSessionName="SagifySession",
-                ExternalId=external_id
-            )
+            if external_id is None:
+                assumedRoleObject = sts_client.assume_role(
+                    RoleArn=aws_role,
+                    RoleSessionName="SagifySession"
+                )
+            else:
+                assumedRoleObject = sts_client.assume_role(
+                    RoleArn=aws_role,
+                    RoleSessionName="SagifySession",
+                    ExternalId=external_id
+                )
 
             credentials = assumedRoleObject['Credentials']
             self.boto_session = boto3.Session(
@@ -35,9 +41,11 @@ class SageMakerClient(object):
                 aws_session_token=credentials['SessionToken'],
                 region_name=aws_region
             )
-        else:
+        elif aws_profile:
             logger.info("No IAM role provided. Using profile {} instead.".format(aws_profile))
             self.boto_session = boto3.Session(profile_name=aws_profile, region_name=aws_region)
+        else:
+            self.boto_session = boto3.Session(region_name=aws_region)
 
         self.sagemaker_client = self.boto_session.client('sagemaker')
         self.sagemaker_session = sage.Session(boto_session=self.boto_session)
@@ -68,6 +76,7 @@ class SageMakerClient(object):
             hyperparameters,
             base_job_name,
             job_name,
+            use_spot_instances=False,
             metric_names=None,
             tags=None
     ):
@@ -85,6 +94,12 @@ class SageMakerClient(object):
         this estimator with
         :param base_job_name: [str], Optional prefix for the SageMaker training job
         :param job_name: [str], Optional name for the SageMaker training job. Overrides `base_job_name`
+        :param use_spot_instances: bool, default=False], Specifies whether to use SageMaker
+                Managed Spot instances for training.
+
+                More information:
+                https://docs.aws.amazon.com/sagemaker/latest/dg/model-managed-spot-training.html
+                (default: ``False``).
         :param metric_names: [list[str], default=None], Optional list of string metric names
         :param tags: [optional[list[dict]], default: None], List of tags for labeling a training
         job. For more, see https://docs.aws.amazon.com/sagemaker/latest/dg/API_Tag.html. Example:
@@ -123,7 +138,9 @@ class SageMakerClient(object):
             hyperparameters=hyperparameters,
             base_job_name=base_job_name,
             sagemaker_session=self.sagemaker_session,
-            metric_definitions=metric_definitions
+            metric_definitions=metric_definitions,
+            train_use_spot_instances=use_spot_instances,
+            train_max_wait=3600 if use_spot_instances else None  # 1 hour
         )
         if tags:
             estimator.tags = tags
@@ -148,6 +165,7 @@ class SageMakerClient(object):
             hyperparams_ranges_dict,
             base_job_name,
             job_name,
+            use_spot_instances=False,
             tags=None,
             wait=False
     ):
@@ -169,6 +187,12 @@ class SageMakerClient(object):
         :param hyperparams_ranges_dict: [dict], Dictionary containing the hyperparameters configuration
         :param base_job_name: [str], Optional prefix for the SageMaker tuning job.
         :param job_name: [str], Optional name for the SageMaker tuning job. Overrides `base_job_name`
+        :param use_spot_instances: bool, default=False], Specifies whether to use SageMaker
+                Managed Spot instances for training.
+
+                More information:
+                https://docs.aws.amazon.com/sagemaker/latest/dg/model-managed-spot-training.html
+                (default: ``False``).
         :param tags: [optional[list[dict]], default: None], List of tags for labeling a training
         job. For more, see https://docs.aws.amazon.com/sagemaker/latest/dg/API_Tag.html. Example:
 
@@ -198,7 +222,9 @@ class SageMakerClient(object):
             train_max_run=max_run,
             input_mode='File',
             output_path=output_path,
-            sagemaker_session=self.sagemaker_session
+            sagemaker_session=self.sagemaker_session,
+            train_use_spot_instances=use_spot_instances,
+            train_max_wait=3600 if use_spot_instances else None  # 1 hour
         )
 
         metric_definitions = [
